/*  gnutrition - a nutrition and diet analysis program.
 *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

void
gnutr_show_msg_no_row_selected( void);

void
on_no_row_selected_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_nutrient_already_selected( void);

void
on_nutrient_already_selected_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_cannot_max_min( void);

void
on_cannot_max_min_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_no_nutrients_selected( void);

void
on_no_nutrients_selected_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_no_ingredient_selected( void);

void
on_no_ingredient_selected_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_no_num_serv( void);

void
on_no_num_serv_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_file_not_found( void);

void
on_file_not_found_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_no_filename_given( void);

void
on_no_filename_given_msgbox_clicked( GnomeDialog *, gint, gpointer);

void
gnutr_show_msg_no_recipe_name( void);

void
on_no_recipe_name_msgbox_clicked( GnomeDialog *, gint, gpointer);
